@@ -32,20 +32,24 @@ class Lotus:
 
     def get_api_signal(self):
         auth = { 'token': self._token }
-        r = requests.get(self._api_endpoint, params=auth)
-        json = r.json()
-        timestamp = parser.parse(json['timestamp'])
-        if self._last_timestamp != timestamp:
-            self._last_timestamp = timestamp
-            if self._last_entry != json['entry'] and self._last_sl != json['stoploss']:
-                self._last_entry = json['entry']
-                self._last_sl = json['stoploss']
-                return json['signal'], json['entry'], json['stoploss']
+        try:
+            r = requests.get(self._api_endpoint, params=auth)
+            json = r.json()
+            timestamp = parser.parse(json['timestamp'])
+            if self._last_timestamp != timestamp:
+                self._last_timestamp = timestamp
+                if self._last_entry != json['entry'] and self._last_sl != json['stoploss']:
+                    self._last_entry = json['entry']
+                    self._last_sl = json['stoploss']
+                    return json['signal'], json['entry'], json['stoploss']
+                else:
+                    return False, False, False
             else:
                 return False, False, False
-        else:
+        except ValueError:
+            print("Can't get signal on endpoint {} with token {}. Please make sure your token and endpoint is set correct.".format(self._api_endpoint, self._token))
             return False, False, False
-
+            
     def rand_sec(self, start=1, end=10):
         return random.randrange(start, end)
 
